@@ -7,6 +7,28 @@ from numbers import Number
 import turtle
 import time
 
+import numpy as np
+
+def _validate_theta(
+        thetas: List[Number], theta_start: Number, theta_stop: Number,
+        theta_step: Number
+    ) -> "np.array":
+    theta_values = (theta_start, theta_stop, theta_step)
+    multiple_thetas = thetas is not None and any(theta_values)
+    if multiple_thetas:
+        raise ValueError((
+            "Multiple definitions of theta were passed in as argument "
+            "which is ambiguous - please define only one set of theta values."
+        ))
+    if thetas is None:
+        if theta_step is None:
+            theta_step = .1
+        thetas = np.arange(theta_start, theta_stop, theta_step)
+    thetas = np.array(thetas)
+    if len(thetas) == 0:
+        raise ValueError("An empty list of thetas was passed in as argument.")
+    return thetas
+
 def _get_products_of_inputs(*args) -> Tuple[Number]:
     """Return a list of tuples that contains all of the input arguments"""
     list_of_lists = [_set_int_to_list(el) for el in args]
@@ -32,17 +54,18 @@ def _draw_animation(
         shapes_arr, screen_size: Tuple[Number, Number] = (1000, 1000),
         screen_color: str = "white", exit_on_click: bool = False,
         color: str = "black", width: Number = 1,
-        frame_pause: Number = 0.1, screen: "turtle.Screen" = None
+        frame_pause: Number = 0.1, screen: "turtle.Screen" = None,
+        screen_coords = (0, 0)
     ) -> None:
     for shape in shapes_arr:
         if screen is not None:
-            screen.clear()
-            screen.setup(*screen_size)
-            screen.bgcolor(screen_color)
-        screen = shape.trace(
+            turtles.shape_turtle.clear()
+            # screen.setup(*screen_size)
+            # screen.bgcolor(screen_color)
+        screen, turtles = shape.trace(
             screen = screen, screen_size = screen_size,
             screen_color = screen_color,
-            color = color, width=width
+            color = color, width=width, screen_coords=screen_coords
         )
         time.sleep(frame_pause)
     if exit_on_click:
